@@ -1,19 +1,25 @@
 package Kelp::Module::WebSocket::AnyEvent;
 
+our $VERSION = '1.02';
+
 use Kelp::Base qw(Kelp::Module::Symbiosis::Base);
 use Plack::App::WebSocket;
 use Kelp::Module::WebSocket::AnyEvent::Connection;
 use Carp qw(croak carp cluck);
 use Try::Tiny;
 
-our $VERSION = '1.01';
-
 attr "-serializer";
 attr "-connections" => sub { {} };
 
-attr "on_open" => sub { sub {} };
-attr "on_close" => sub { sub {} };
-attr "on_message" => sub { sub {} };
+attr "on_open" => sub {
+	sub { }
+};
+attr "on_close" => sub {
+	sub { }
+};
+attr "on_message" => sub {
+	sub { }
+};
 attr "on_error";
 
 # This function is here to work around Twiggy bug that is silencing errors
@@ -23,7 +29,8 @@ sub _trap(&)
 	my ($block) = @_;
 	try {
 		$block->();
-	} catch {
+	}
+	catch {
 		cluck $_;
 		die $_;
 	};
@@ -35,6 +42,7 @@ sub psgi
 
 	my $conn_max_id = 0;
 	my $websocket = Plack::App::WebSocket->new(
+
 		# on_error - optional
 		(defined $self->on_error ? (on_error => sub { $self->on_error->(@_) }) : ()),
 
@@ -112,9 +120,9 @@ Kelp::Module::WebSocket::AnyEvent - AnyEvent websocket server integration with K
 =head1 SYNOPSIS
 
 	# in config
-	modules => [qw(Symbiosis Websocket::AnyEvent)],
+	modules => [qw(Symbiosis WebSocket::AnyEvent)],
 	modules_init => {
-		"Websocket::AnyEvent" => {
+		"WebSocket::AnyEvent" => {
 			serializer => "json",
 		},
 	},
@@ -172,7 +180,7 @@ Registers a $handler (coderef) for websocket $event (string). Handler will be pa
 
 =over 2
 
-=item * L<Dancer2::Plugin::Websocket>, same integration for Dancer2 framework this module was inspired by
+=item * L<Dancer2::Plugin::WebSocket>, same integration for Dancer2 framework this module was inspired by
 
 =item * L<Kelp>, the framework
 
